==> ace_5.4.2.1.0.orig.tar.gz: ACE_wrappers/TAO/TAO_IDL/fe/fe_extern.cpp <==
// This may look like C, but it's really -*- C++ -*-
// fe_extern.cpp,v 1.12 2004/07/19 16:18:28 parsons Exp

/*

COPYRIGHT

Copyright 1992, 1993, 1994 Sun Microsystems, Inc.  Printed in the United
States of America.  All Rights Reserved.

This product is protected by copyright and distributed under the following
license restricting its use.

The Interface Definition Language Compiler Front End (CFE) is made
available for your use provided that you include this license and copyright
notice on all media and documentation and the software program in which
this product is incorporated in whole or part. You may copy and extend
functionality (but may not remove functionality) of the Interface
Definition Language CFE without charge, but you are not authorized to
license or distribute it to anyone else except as part of a product or
program developed by you or with the express written consent of Sun
Microsystems, Inc. ("Sun").

The names of Sun Microsystems, Inc. and any of its subsidiaries or
affiliates may not be used in advertising or publicity pertaining to
distribution of Interface Definition Language CFE as permitted herein.

This license is effective until terminated by Sun for failure to comply
with this license.  Upon termination, you shall destroy or return all code
and documentation for the Interface Definition Language CFE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED AS IS WITH NO WARRANTIES OF
ANY KIND INCLUDING THE WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS
FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR ARISING FROM A COURSE OF
DEALING, USAGE OR TRADE PRACTICE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED WITH NO SUPPORT AND WITHOUT
ANY OBLIGATION ON THE PART OF Sun OR ANY OF ITS SUBSIDIARIES OR AFFILIATES
TO ASSIST IN ITS USE, CORRECTION, MODIFICATION OR ENHANCEMENT.

SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES SHALL HAVE NO LIABILITY WITH
RESPECT TO THE INFRINGEMENT OF COPYRIGHTS, TRADE SECRETS OR ANY PATENTS BY
INTERFACE DEFINITION LANGUAGE CFE OR ANY PART THEREOF.

IN NO EVENT WILL SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES BE LIABLE FOR
ANY LOST REVENUE OR PROFITS OR OTHER SPECIAL, INDIRECT AND CONSEQUENTIAL
DAMAGES, EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

Use, duplication, or disclosure by the government is subject to
restrictions as set forth in subparagraph (c)(1)(ii) of the Rights in
Technical Data and Computer Software clause at DFARS 252.227-7013 and FAR
52.227-19.

Sun, Sun Microsystems and the Sun logo are trademarks or registered
trademarks of Sun Microsystems, Inc.

SunSoft, Inc.
2550 Garcia Avenue
Mountain View, California  94043

NOTE:

SunOS, SunSoft, Sun, Solaris, Sun Microsystems or the Sun logo are
trademarks or registered trademarks of Sun Microsystems, Inc.

 */

/*
 * fe_extern.cc - export FE interfaces to driver
 */

#include "fe_extern.h"
#include "ast_root.h"
#include "global_extern.h"
#include "utl_err.h"
#include "utl_indenter.h"
#include "ace/UUID.h"

ACE_RCSID (fe,
           fe_extern,
           "fe_extern.cpp,v 1.12 2004/07/19 16:18:28 parsons Exp")

extern int tao_yyparse (void);
extern FILE *tao_yyin;

int
FE_yyparse (void)
{
  int result = tao_yyparse ();

  if (idl_global->err_count () == 0)
    {
      idl_global->root ()->call_add ();
    }

  return result;
}

void
FE_set_yyin (File *f)
{
  tao_yyin = reinterpret_cast<FILE *> (f);
}

// Constructor interfaces.

UTL_Error *
FE_new_UTL_Error (void)
{
  UTL_Error *retval = 0;
  ACE_NEW_RETURN (retval,
                  UTL_Error,
                  0);

  return retval;
}

UTL_Indenter *
FE_new_UTL_Indenter (void)
{
  UTL_Indenter *retval = 0;
  ACE_NEW_RETURN (retval,
                  UTL_Indenter,
                  0);

  return retval;
}

// Utility method.

ACE_CString
FE_generate_UUID (void)
{
  ACE_Utils::UUID* uuid =
    ACE_Utils::UUID_GENERATOR::instance ()->generateUUID ();
    
  const ACE_CString *tmp = uuid->to_string ();
  ACE_CString retval = *tmp;
  delete uuid;
  
  return retval;
}

==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/TAO_IDL/fe/fe_extern.cpp <==
// This may look like C, but it's really -*- C++ -*-
// fe_extern.cpp,v 1.13 2005/06/10 13:25:02 parsons Exp

/*

COPYRIGHT

Copyright 1992, 1993, 1994 Sun Microsystems, Inc.  Printed in the United
States of America.  All Rights Reserved.

This product is protected by copyright and distributed under the following
license restricting its use.

The Interface Definition Language Compiler Front End (CFE) is made
available for your use provided that you include this license and copyright
notice on all media and documentation and the software program in which
this product is incorporated in whole or part. You may copy and extend
functionality (but may not remove functionality) of the Interface
Definition Language CFE without charge, but you are not authorized to
license or distribute it to anyone else except as part of a product or
program developed by you or with the express written consent of Sun
Microsystems, Inc. ("Sun").

The names of Sun Microsystems, Inc. and any of its subsidiaries or
affiliates may not be used in advertising or publicity pertaining to
distribution of Interface Definition Language CFE as permitted herein.

This license is effective until terminated by Sun for failure to comply
with this license.  Upon termination, you shall destroy or return all code
and documentation for the Interface Definition Language CFE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED AS IS WITH NO WARRANTIES OF
ANY KIND INCLUDING THE WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS
FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR ARISING FROM A COURSE OF
DEALING, USAGE OR TRADE PRACTICE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED WITH NO SUPPORT AND WITHOUT
ANY OBLIGATION ON THE PART OF Sun OR ANY OF ITS SUBSIDIARIES OR AFFILIATES
TO ASSIST IN ITS USE, CORRECTION, MODIFICATION OR ENHANCEMENT.

SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES SHALL HAVE NO LIABILITY WITH
RESPECT TO THE INFRINGEMENT OF COPYRIGHTS, TRADE SECRETS OR ANY PATENTS BY
INTERFACE DEFINITION LANGUAGE CFE OR ANY PART THEREOF.

IN NO EVENT WILL SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES BE LIABLE FOR
ANY LOST REVENUE OR PROFITS OR OTHER SPECIAL, INDIRECT AND CONSEQUENTIAL
DAMAGES, EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

Use, duplication, or disclosure by the government is subject to
restrictions as set forth in subparagraph (c)(1)(ii) of the Rights in
Technical Data and Computer Software clause at DFARS 252.227-7013 and FAR
52.227-19.

Sun, Sun Microsystems and the Sun logo are trademarks or registered
trademarks of Sun Microsystems, Inc.

SunSoft, Inc.
2550 Garcia Avenue
Mountain View, California  94043

NOTE:

SunOS, SunSoft, Sun, Solaris, Sun Microsystems or the Sun logo are
trademarks or registered trademarks of Sun Microsystems, Inc.

 */

/*
 * fe_extern.cc - export FE interfaces to driver
 */

#include "fe_extern.h"
#include "ast_root.h"
#include "global_extern.h"
#include "utl_err.h"
#include "utl_indenter.h"
#include "ace/UUID.h"

ACE_RCSID (fe,
           fe_extern,
           "fe_extern.cpp,v 1.13 2005/06/10 13:25:02 parsons Exp")

extern int tao_yyparse (void);
extern FILE *tao_yyin;

int
FE_yyparse (void)
{
  int result = tao_yyparse ();

  if (idl_global->err_count () == 0)
    {
      idl_global->root ()->call_add ();
    }

  return result;
}

void
FE_set_yyin (File *f)
{
  tao_yyin = reinterpret_cast<FILE *> (f);
}

// Constructor interfaces.

UTL_Error *
FE_new_UTL_Error (void)
{
  UTL_Error *retval = 0;
  ACE_NEW_RETURN (retval,
                  UTL_Error,
                  0);

  return retval;
}

UTL_Indenter *
FE_new_UTL_Indenter (void)
{
  UTL_Indenter *retval = 0;
  ACE_NEW_RETURN (retval,
                  UTL_Indenter,
                  0);

  return retval;
}

// Utility method.

ACE_CString
FE_generate_UUID (void)
{
  ACE_Utils::UUID uuid;
  
  // The 0xc0 arg triggers use of the thread id in creating the UUID,
  // useful when the IDL compiler is run by multiple threads in the
  // same process.
  ACE_Utils::UUID_GENERATOR::instance ()->generateUUID (uuid, 
                                                        0x0001,
                                                        0xc0);
    
  return *uuid.to_string ();
}
